@@ -12,6 +12,9 @@ sub handle {
     # inherit the settings from the parent hash
     foreach (keys (%$parent_hash)) { $hash->{$_} = $parent_hash->{$_} }
     
+    my $file_name = $parent_hash->{basename} || '';
+    $hash->{"file_$file_name"} = 1;
+
     return $hash;
 }
 
